==> style-o-matic-1.1.5.tgz: package/es/components/Dropdown/DropdownToggle.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, setCorePropDefaults, getValidProps, ROLE } from "../../lib";

var DropdownToggle = (_temp = _class = function (_CoreComponent) {
  _inherits(DropdownToggle, _CoreComponent);

  function DropdownToggle() {
    _classCallCheck(this, DropdownToggle);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  DropdownToggle.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        open = _getValidProps.open,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var caretClass = open ? "fa-caret-down" : "fa-caret-right";

    return React.createElement(
      Component,
      props,
      children,
      React.createElement("span", { className: "ui-dropdown-caret fa " + caretClass })
    );
  };

  return DropdownToggle;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "button",
  uirole: ROLE.TOGGLE
}), _temp);


export default DropdownToggle;

==> style-o-matic-1.1.37.tgz: package/es/components/Dropdown/DropdownToggle.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, getCorePropDefaults, getValidProps, ROLE } from "../../lib";

var DropdownToggle = (_temp = _class = function (_CoreComponent) {
  _inherits(DropdownToggle, _CoreComponent);

  function DropdownToggle() {
    _classCallCheck(this, DropdownToggle);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  DropdownToggle.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        open = _getValidProps.open,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var caretClass = open ? "fa-caret-down" : "fa-caret-right";

    return React.createElement(
      Component,
      props,
      children,
      React.createElement("span", { className: "ui-dropdown-caret fa " + caretClass })
    );
  };

  return DropdownToggle;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  renderAs: "button",
  uirole: ROLE.TOGGLE
}), _temp);


export default DropdownToggle;
